==> webdriver-sync-0.16.5.tgz: package/src/classPaths.js <==
'use strict';

module.exports = {
  By: 'org.openqa.selenium.By',
  ChromeDriver: 'org.openqa.selenium.chrome.ChromeDriver',
  ChromeDriverService: 'org.openqa.selenium.chrome.ChromeDriverService',
  ChromeDriverServiceBuilder: 'org.openqa.selenium.chrome.ChromeDriverService$Builder',
  ChromeOptions: 'org.openqa.selenium.chrome.ChromeOptions',
  Command: 'org.openqa.selenium.remote.Command',
  Cookie: 'org.openqa.selenium.Cookie',
  Date: 'java.util.Date',
  DesiredCapabilities: 'org.openqa.selenium.remote.DesiredCapabilities',
  Dimension: 'org.openqa.selenium.Dimension',
  DriverService: 'org.openqa.selenium.remote.service.DriverService',
  ErrorHandler: 'org.openqa.selenium.remote.ErrorHandler',
  ExpectedConditions: 'org.openqa.selenium.support.ui.ExpectedConditions',
  File: 'java.io.File',
  FirefoxDriver: 'org.openqa.selenium.firefox.FirefoxDriver',
  FirefoxProfile: 'org.openqa.selenium.firefox.FirefoxProfile',
  PhantomJSDriver: 'org.openqa.selenium.phantomjs.PhantomJSDriver',
  HtmlUnitDriver: 'org.openqa.selenium.htmlunit.HtmlUnitDriver',
  InternetExplorerDriver: 'org.openqa.selenium.ie.InternetExplorerDriver',
  Keys: 'org.openqa.selenium.Keys',
  Level: 'java.util.logging.Level',
  List: 'java.util.List',
  LocalFileDetector: 'org.openqa.selenium.remote.LocalFileDetector',
  LogEntry: 'org.openqa.selenium.logging.LogEntry',
  Long: 'java.lang.Long',
  LoggingPreferences: 'org.openqa.selenium.logging.LoggingPreferences',
  Map: 'java.util.Map',
  OutputType: 'org.openqa.selenium.OutputType',
  Platform: 'org.openqa.selenium.Platform',
  Point: 'org.openqa.selenium.Point',
  RemoteStatus: 'org.openqa.selenium.remote.RemoteStatus',
  RemoteWebDriver: 'org.openqa.selenium.remote.RemoteWebDriver',
  Response: 'org.openqa.selenium.remote.Response',
  SafariDriver: 'org.openqa.selenium.safari.SafariDriver',
  SessionId: 'org.openqa.selenium.remote.SessionId',
  TimeUnit: 'java.util.concurrent.TimeUnit',
  URL: 'java.net.URL',
  UselessFileDetector: 'org.openqa.selenium.remote.UselessFileDetector',
  UserAndPassword: 'org.openqa.selenium.security.UserAndPassword',
  WebDriverWait: 'org.openqa.selenium.support.ui.WebDriverWait',
  WebElement: 'org.openqa.selenium.WebElement'
};

==> webdriver-sync-1.0.1.tgz: package/src/classPaths.js <==
'use strict';

module.exports = {
  By: 'org.openqa.selenium.By',
  ChromeDriver: 'org.openqa.selenium.chrome.ChromeDriver',
  ChromeDriverService: 'org.openqa.selenium.chrome.ChromeDriverService',
  ChromeDriverServiceBuilder: 'org.openqa.selenium.chrome.ChromeDriverService$Builder',
  ChromeOptions: 'org.openqa.selenium.chrome.ChromeOptions',
  Command: 'org.openqa.selenium.remote.Command',
  Cookie: 'org.openqa.selenium.Cookie',
  Date: 'java.util.Date',
  DesiredCapabilities: 'org.openqa.selenium.remote.DesiredCapabilities',
  Dimension: 'org.openqa.selenium.Dimension',
  DriverService: 'org.openqa.selenium.remote.service.DriverService',
  ErrorHandler: 'org.openqa.selenium.remote.ErrorHandler',
  ExpectedConditions: 'org.openqa.selenium.support.ui.ExpectedConditions',
  File: 'java.io.File',
  FirefoxDriver: 'org.openqa.selenium.firefox.FirefoxDriver',
  FirefoxProfile: 'org.openqa.selenium.firefox.FirefoxProfile',
  // PhantomJSDriver: 'org.openqa.selenium.phantomjs.PhantomJSDriver',
  HtmlUnitDriver: 'org.openqa.selenium.htmlunit.HtmlUnitDriver',
  InternetExplorerDriver: 'org.openqa.selenium.ie.InternetExplorerDriver',
  Keys: 'org.openqa.selenium.Keys',
  Level: 'java.util.logging.Level',
  List: 'java.util.List',
  LocalFileDetector: 'org.openqa.selenium.remote.LocalFileDetector',
  LogEntry: 'org.openqa.selenium.logging.LogEntry',
  Long: 'java.lang.Long',
  LoggingPreferences: 'org.openqa.selenium.logging.LoggingPreferences',
  Map: 'java.util.Map',
  OutputType: 'org.openqa.selenium.OutputType',
  Platform: 'org.openqa.selenium.Platform',
  Point: 'org.openqa.selenium.Point',
  RemoteStatus: 'org.openqa.selenium.remote.RemoteStatus',
  RemoteWebDriver: 'org.openqa.selenium.remote.RemoteWebDriver',
  Response: 'org.openqa.selenium.remote.Response',
  SafariDriver: 'org.openqa.selenium.safari.SafariDriver',
  SessionId: 'org.openqa.selenium.remote.SessionId',
  TimeUnit: 'java.util.concurrent.TimeUnit',
  URL: 'java.net.URL',
  UselessFileDetector: 'org.openqa.selenium.remote.UselessFileDetector',
  // UserAndPassword: 'org.openqa.selenium.security.UserAndPassword',
  WebDriverWait: 'org.openqa.selenium.support.ui.WebDriverWait',
  WebElement: 'org.openqa.selenium.WebElement'
};
